Stoq - Gestão comercial open source

#

## Gestão comercial open source

Bem vindo ao Stoq

## Conteúdo

- Sobre o Stoq
- Contato Comercial
- Contato Técnico
- Licença

### Sobre o Stoq

Bem-vindo ao Stoq!

Stoq está configurado em modo de demonstração, para que você possa fazer um test-drive.

Durante o uso do modo de demonstração, o plugins ECF estará habilitado e utilizará um emulador de impressora fiscal para que o usuário tenha a sensação de como é o sistema em produção.

Após a instalação e a habilitação do modo de produção, o emulador e limitações são removidos.

Caso seja solicitado o nome do usuário e senha, estes são:

- usuário: admin
- senha: admin

### Contato Comercial

Para tratar assuntos comerciais, fazer um primeiro contato para uma proposta nova ou agendar uma visita, entre em contato com nosso departamento comercial <comercial@stoq.com.br>.

O telefone para contato é (16) 3376-0125

### Contato Técnico

Para contactar a equipe do projeto Stoq, ou para encaminhar dúvidas, sugestões ou soluções utilize as listas de discussão.

Para tratar de assuntos técnicos como desenvolvimento, arquitetura e usabilidade, é recomendado falar com o responsável pelo projeto, Christian Reis <comercial@stoq.com.br>.

Caso possua uma conexão à internet disponível, você pode entrar em contato pelo nosso chat online.

### Licença

Este software é coberto pela GPL ('General Public License' ou 'Licença Pública Geral do GNU') (versão 2.0). Basicamente você é livre para utilizá-lo, distribuí-lo, alterar seu conteúdo e até mesmo vendê-lo para qualquer pessoa, desde que os créditos aos autores originais sejam mantidos. Você pode instalá-lo em quantos micros quiser ou vender micros com o Stoq pré-instalado, não precisando nenhum tipo de comunicado ou pagamento de licença.

Em troca você concorda que está usando este software sob sua própria vontade e aceitando qualquer tipo de risco ou dano advindo de sua utilização. A Async Open Source não poderá ser responsabilizada por qualquer tipo de dano causado por seu uso. Concorda ainda que não existe nenhuma garantia de que ele realmente irá funcionar no seu computador e que o fato de utilizá-lo não lhe dá direito a nenhum tipo de suporte técnico, embora você seja bem vindo para postar suas dúvidas nas listas de discussão do produto ou mesmo solicitar a contratação de suporte técnico pago.